.. _reference_material:

########################
Configuration and output
########################

.. grid:: 1 1 2 2
    :gutter: 3

    .. grid-item-card::
        :link: inifile
        :link-type: ref

        .. toctree::
            :maxdepth: 1

            inifile.rst

        Instructions for creating configurations files and explanations of each option.

    .. grid-item-card::
        :link: output_info
        :link-type: ref

        .. toctree::
            :maxdepth: 1

            output_info.rst

        Descriptions of the output files generated by COSMIC simulations.